aboutsummaryrefslogtreecommitdiffstats
path: root/build
diff options
context:
space:
mode:
Diffstat (limited to 'build')
-rwxr-xr-xbuild/bls-arm64.sh2
-rw-r--r--build/ci.go80
-rw-r--r--build/deb/dexon-swarm/deb.control4
-rw-r--r--build/deb/dexon/deb.control4
-rwxr-xr-xbuild/env.sh10
-rw-r--r--build/mvn.pom6
-rw-r--r--build/nsis.install.nsh6
-rw-r--r--build/pod.podspec4
-rw-r--r--build/testtool/testtool.go20
9 files changed, 68 insertions, 68 deletions
diff --git a/build/bls-arm64.sh b/build/bls-arm64.sh
index e2046dee0..d2e82bec0 100755
--- a/build/bls-arm64.sh
+++ b/build/bls-arm64.sh
@@ -1,6 +1,6 @@
#!/bin/bash -f
-cd vendor/github.com/dexon-foundation/
+cd vendor/github.com/tangerine-network/
sudo apt-get update
diff --git a/build/deb/dexon-swarm/deb.control b/build/deb/dexon-swarm/deb.control
index b787fe391..41727ea85 100644
--- a/build/deb/dexon-swarm/deb.control
+++ b/build/deb/dexon-swarm/deb.control
@@ -5,8 +5,8 @@ Maintainer: {{.Author}}
Build-Depends: debhelper (>= 8.0.0), golang-1.10
Standards-Version: 3.9.5
Homepage: https://ethereum.org
-Vcs-Git: git://github.com/dexon-foundation/dexon.git
-Vcs-Browser: https://github.com/dexon-foundation/dexon
+Vcs-Git: git://github.com/tangerine-network/go-tangerine.git
+Vcs-Browser: https://github.com/tangerine-network/go-tangerine
{{range .Executables}}
Package: {{$.ExeName .}}
diff --git a/build/deb/dexon/deb.control b/build/deb/dexon/deb.control
index 6d9c51346..113ed8389 100644
--- a/build/deb/dexon/deb.control
+++ b/build/deb/dexon/deb.control
@@ -5,8 +5,8 @@ Maintainer: {{.Author}}
Build-Depends: debhelper (>= 8.0.0), golang-1.10
Standards-Version: 3.9.5
Homepage: https://ethereum.org
-Vcs-Git: git://github.com/dexon-foundation/dexon.git
-Vcs-Browser: https://github.com/dexon-foundation/dexon
+Vcs-Git: git://github.com/tangerine-network/go-tangerine.git
+Vcs-Browser: https://github.com/tangerine-network/go-tangerine
Package: {{.Name}}
Architecture: any
diff --git a/build/env.sh b/build/env.sh
index aa7aeba95..720d12bab 100755
--- a/build/env.sh
+++ b/build/env.sh
@@ -10,11 +10,11 @@ fi
# Create fake Go workspace if it doesn't exist yet.
workspace="$PWD/build/_workspace"
root="$PWD"
-ethdir="$workspace/src/github.com/dexon-foundation"
-if [ ! -L "$ethdir/dexon" ]; then
+ethdir="$workspace/src/github.com/tangerine-network"
+if [ ! -L "$ethdir/go-tangerine" ]; then
mkdir -p "$ethdir"
cd "$ethdir"
- ln -s ../../../../../. dexon
+ ln -s ../../../../../. go-tangerine
cd "$root"
fi
@@ -23,8 +23,8 @@ GOPATH="$workspace"
export GOPATH
# Run the command inside the workspace.
-cd "$ethdir/dexon"
-PWD="$ethdir/dexon"
+cd "$ethdir/go-tangerine"
+PWD="$ethdir/go-tangerine"
# Launch the arguments with the configured environment.
exec "$@"
diff --git a/build/mvn.pom b/build/mvn.pom
index 41f01204b..b323b5304 100644
--- a/build/mvn.pom
+++ b/build/mvn.pom
@@ -11,7 +11,7 @@
<name>Android Ethereum Client</name>
<description>Android port of the go-ethereum libraries and node</description>
- <url>https://github.com/dexon-foundation/dexon</url>
+ <url>https://github.com/tangerine-network/go-tangerine</url>
<inceptionYear>2015</inceptionYear>
<licenses>
@@ -48,10 +48,10 @@
<issueManagement>
<system>GitHub Issues</system>
- <url>https://github.com/dexon-foundation/dexon/issues/</url>
+ <url>https://github.com/tangerine-network/go-tangerine/issues/</url>
</issueManagement>
<scm>
- <url>https://github.com/dexon-foundation/dexon</url>
+ <url>https://github.com/tangerine-network/go-tangerine</url>
</scm>
</project>
diff --git a/build/nsis.install.nsh b/build/nsis.install.nsh
index 9f8f54b14..553ecb0fa 100644
--- a/build/nsis.install.nsh
+++ b/build/nsis.install.nsh
@@ -3,9 +3,9 @@ InstallDir "$InstDir"
OutFile "${OUTPUTFILE}" # set through command line arguments
# Links for "Add/Remove Programs"
-!define HELPURL "https://github.com/dexon-foundation/dexon/issues"
-!define UPDATEURL "https://github.com/dexon-foundation/dexon/releases"
-!define ABOUTURL "https://github.com/dexon-foundation/dexon#ethereum-go"
+!define HELPURL "https://github.com/tangerine-network/go-tangerine/issues"
+!define UPDATEURL "https://github.com/tangerine-network/go-tangerine/releases"
+!define ABOUTURL "https://github.com/tangerine-network/go-tangerine#ethereum-go"
!define /date NOW "%Y%m%d"
PageEx license
diff --git a/build/pod.podspec b/build/pod.podspec
index fe60f9f68..d47d7afff 100644
--- a/build/pod.podspec
+++ b/build/pod.podspec
@@ -2,12 +2,12 @@ Pod::Spec.new do |spec|
spec.name = 'Geth'
spec.version = '{{.Version}}'
spec.license = { :type => 'GNU Lesser General Public License, Version 3.0' }
- spec.homepage = 'https://github.com/dexon-foundation/dexon'
+ spec.homepage = 'https://github.com/tangerine-network/go-tangerine'
spec.authors = { {{range .Contributors}}
'{{.Name}}' => '{{.Email}}',{{end}}
}
spec.summary = 'iOS Ethereum Client'
- spec.source = { :git => 'https://github.com/dexon-foundation/dexon.git', :commit => '{{.Commit}}' }
+ spec.source = { :git => 'https://github.com/tangerine-network/go-tangerine.git', :commit => '{{.Commit}}' }
spec.platform = :ios
spec.ios.deployment_target = '9.0'
diff --git a/build/testtool/testtool.go b/build/testtool/testtool.go
index a801cfbb3..15659f656 100644
--- a/build/testtool/testtool.go
+++ b/build/testtool/testtool.go
@@ -11,16 +11,16 @@ import (
"strings"
"time"
- dexCore "github.com/dexon-foundation/dexon-consensus/core"
-
- "github.com/dexon-foundation/dexon"
- "github.com/dexon-foundation/dexon/accounts/abi"
- "github.com/dexon-foundation/dexon/cmd/zoo/monkey"
- "github.com/dexon-foundation/dexon/core/types"
- "github.com/dexon-foundation/dexon/core/vm"
- "github.com/dexon-foundation/dexon/crypto"
- "github.com/dexon-foundation/dexon/ethclient"
- "github.com/dexon-foundation/dexon/internal/build"
+ dexCore "github.com/byzantine-lab/dexon-consensus/core"
+
+ ethereum "github.com/tangerine-network/go-tangerine"
+ "github.com/tangerine-network/go-tangerine/accounts/abi"
+ "github.com/tangerine-network/go-tangerine/cmd/zoo/monkey"
+ "github.com/tangerine-network/go-tangerine/core/types"
+ "github.com/tangerine-network/go-tangerine/core/vm"
+ "github.com/tangerine-network/go-tangerine/crypto"
+ "github.com/tangerine-network/go-tangerine/ethclient"
+ "github.com/tangerine-network/go-tangerine/internal/build"
)
func main() {
diff --git a/build/ci.go b/build/ci.go
index 931fa2f83..ea9fddd03 100644
--- a/build/ci.go
+++ b/build/ci.go
@@ -58,25 +58,25 @@ import (
"strings"
"time"
- "github.com/dexon-foundation/dexon/internal/build"
- "github.com/dexon-foundation/dexon/params"
- sv "github.com/dexon-foundation/dexon/swarm/version"
+ "github.com/tangerine-network/go-tangerine/internal/build"
+ "github.com/tangerine-network/go-tangerine/params"
+ sv "github.com/tangerine-network/go-tangerine/swarm/version"
)
var (
- // Files that end up in the gdex*.zip archive.
- gdexArchiveFiles = []string{
+ // Files that end up in the gtan*.zip archive.
+ gtanArchiveFiles = []string{
"COPYING",
- executablePath("gdex"),
+ executablePath("gtan"),
}
// Files that end up in the gdex-alltools*.zip archive.
allToolsArchiveFiles = []string{
"COPYING",
executablePath("abigen"),
executablePath("bootnode"),
executablePath("evm"),
- executablePath("gdex"),
+ executablePath("gtan"),
executablePath("puppeth"),
executablePath("rlpdump"),
executablePath("wnode"),
@@ -92,23 +92,23 @@ var (
debExecutables = []debExecutable{
{
BinaryName: "abigen",
- Description: "Source code generator to convert Dexon contract definitions into easy to use, compile-time type-safe Go packages.",
+ Description: "Source code generator to convert Tangerine contract definitions into easy to use, compile-time type-safe Go packages.",
},
{
BinaryName: "bootnode",
- Description: "Dexon bootnode.",
+ Description: "Tangerine bootnode.",
},
{
BinaryName: "evm",
- Description: "Developer utility version of the EVM (Dexon Virtual Machine) that is capable of running bytecode snippets within a configurable environment and execution mode.",
+ Description: "Developer utility version of the EVM (Tangerine Virtual Machine) that is capable of running bytecode snippets within a configurable environment and execution mode.",
},
{
- BinaryName: "gdex",
- Description: "Dexon CLI client.",
+ BinaryName: "gtan",
+ Description: "Tangerine CLI client.",
},
{
BinaryName: "puppeth",
- Description: "Dexon private network manager.",
+ Description: "Tangerine private network manager.",
},
{
BinaryName: "rlpdump",
@@ -116,7 +116,7 @@ var (
},
{
BinaryName: "wnode",
- Description: "Dexon Whisper diagnostic tool",
+ Description: "Tangerine Whisper diagnostic tool",
},
}
@@ -125,11 +125,11 @@ var (
{
BinaryName: "swarm",
PackageName: "dexon-swarm",
- Description: "Dexon Swarm daemon and tools",
+ Description: "Tangerine Swarm daemon and tools",
},
}
- debDexon = debPackage{
+ debTangerine = debPackage{
Name: "dexon",
Version: params.Version,
Executables: debExecutables,
@@ -144,7 +144,7 @@ var (
// Debian meta packages to build and push to Ubuntu PPA
debPackages = []debPackage{
debSwarm,
- debDexon,
+ debTangerine,
}
// Packages to be cross-compiled by the xgo command
@@ -422,15 +422,15 @@ func doArchive(cmdline []string) {
var (
env = build.Env()
- basegdex = archiveBasename(*arch, params.ArchiveVersion(env.Commit))
- gdex = "gdex-" + basegdex + ext
- alltools = "gdex-alltools-" + basegdex + ext
+ basegtan = archiveBasename(*arch, params.ArchiveVersion(env.Commit))
+ gtan = "gtan-" + basegtan + ext
+ alltools = "gtan-alltools-" + basegtan + ext
baseswarm = archiveBasename(*arch, sv.ArchiveVersion(env.Commit))
swarm = "swarm-" + baseswarm + ext
)
maybeSkipArchive(env)
- if err := build.WriteArchive(gdex, gdexArchiveFiles); err != nil {
+ if err := build.WriteArchive(gtan, gtanArchiveFiles); err != nil {
log.Fatal(err)
}
if err := build.WriteArchive(alltools, allToolsArchiveFiles); err != nil {
@@ -439,7 +439,7 @@ func doArchive(cmdline []string) {
if err := build.WriteArchive(swarm, swarmArchiveFiles); err != nil {
log.Fatal(err)
}
- for _, archive := range []string{gdex, alltools, swarm} {
+ for _, archive := range []string{gtan, alltools, swarm} {
if err := archiveUpload(archive, *upload, *signer); err != nil {
log.Fatal(err)
}
@@ -584,7 +584,7 @@ func makeWorkdir(wdflag string) string {
if wdflag != "" {
err = os.MkdirAll(wdflag, 0744)
} else {
- wdflag, err = ioutil.TempDir("", "gdex-build-")
+ wdflag, err = ioutil.TempDir("", "gtan-build-")
}
if err != nil {
log.Fatal(err)
@@ -638,7 +638,7 @@ func (d debExecutable) Package() string {
func newDebMetadata(distro, author string, env build.Environment, t time.Time, name string, version string, exes []debExecutable) debMetadata {
if author == "" {
// No signing key, use default author.
- author = "Dexon Builds <fjl@dexon.org>"
+ author = "Tangerine Builds <fjl@dexon.org>"
}
return debMetadata{
PackageName: name,
@@ -752,28 +752,28 @@ func doWindowsInstaller(cmdline []string) {
var (
devTools []string
allTools []string
- gdexTool string
+ gtanTool string
)
for _, file := range allToolsArchiveFiles {
if file == "COPYING" { // license, copied later
continue
}
allTools = append(allTools, filepath.Base(file))
- if filepath.Base(file) == "gdex.exe" {
- gdexTool = file
+ if filepath.Base(file) == "gtan.exe" {
+ gtanTool = file
} else {
devTools = append(devTools, file)
}
}
// Render NSIS scripts: Installer NSIS contains two installer sections,
// first section contains the gdex binary, second section holds the dev tools.
templateData := map[string]interface{}{
"License": "COPYING",
- "Gdex": gdexTool,
+ "Gdex": gtanTool,
"DevTools": devTools,
}
- build.Render("build/nsis.gdex.nsi", filepath.Join(*workdir, "gdex.nsi"), 0644, nil)
+ build.Render("build/nsis.gtan.nsi", filepath.Join(*workdir, "gtan.nsi"), 0644, nil)
build.Render("build/nsis.install.nsh", filepath.Join(*workdir, "install.nsh"), 0644, templateData)
build.Render("build/nsis.uninstall.nsh", filepath.Join(*workdir, "uninstall.nsh"), 0644, allTools)
build.Render("build/nsis.pathupdate.nsh", filepath.Join(*workdir, "PathUpdate.nsh"), 0644, nil)
@@ -788,14 +788,14 @@ func doWindowsInstaller(cmdline []string) {
if env.Commit != "" {
version[2] += "-" + env.Commit[:8]
}
- installer, _ := filepath.Abs("gdex-" + archiveBasename(*arch, params.ArchiveVersion(env.Commit)) + ".exe")
+ installer, _ := filepath.Abs("gtan-" + archiveBasename(*arch, params.ArchiveVersion(env.Commit)) + ".exe")
build.MustRunCommand("makensis.exe",
"/DOUTPUTFILE="+installer,
"/DMAJORVERSION="+version[0],
"/DMINORVERSION="+version[1],
"/DBUILDVERSION="+version[2],
"/DARCH="+*arch,
- filepath.Join(*workdir, "gdex.nsi"),
+ filepath.Join(*workdir, "gtan.nsi"),
)
// Sign and publish installer.
@@ -826,11 +826,11 @@ func doAndroidArchive(cmdline []string) {
// Build the Android archive and Maven resources
build.MustRun(goTool("get", "golang.org/x/mobile/cmd/gomobile", "golang.org/x/mobile/cmd/gobind"))
build.MustRun(gomobileTool("init", "--ndk", os.Getenv("ANDROID_NDK")))
- build.MustRun(gomobileTool("bind", "-ldflags", "-s -w", "--target", "android", "--javapkg", "org.dexon", "-v", "github.com/dexon-foundation/dexon/mobile"))
+ build.MustRun(gomobileTool("bind", "-ldflags", "-s -w", "--target", "android", "--javapkg", "org.dexon", "-v", "github.com/tangerine-network/go-tangerine/mobile"))
if *local {
// If we're building locally, copy bundle to build dir and skip Maven
- os.Rename("gdex.aar", filepath.Join(GOBIN, "gdex.aar"))
+ os.Rename("gtan.aar", filepath.Join(GOBIN, "gtan.aar"))
return
}
meta := newMavenMetadata(env)
@@ -840,8 +840,8 @@ func doAndroidArchive(cmdline []string) {
maybeSkipArchive(env)
// Sign and upload the archive to Azure
- archive := "gdex-" + archiveBasename("android", params.ArchiveVersion(env.Commit)) + ".aar"
- os.Rename("gdex.aar", archive)
+ archive := "gtan-" + archiveBasename("android", params.ArchiveVersion(env.Commit)) + ".aar"
+ os.Rename("gtan.aar", archive)
if err := archiveUpload(archive, *upload, *signer); err != nil {
log.Fatal(err)
@@ -926,7 +926,7 @@ func newMavenMetadata(env build.Environment) mavenMetadata {
}
return mavenMetadata{
Version: version,
- Package: "gdex-" + version,
+ Package: "gtan-" + version,
Develop: isUnstableBuild(env),
Contributors: contribs,
}
@@ -947,7 +947,7 @@ func doXCodeFramework(cmdline []string) {
// Build the iOS XCode framework
build.MustRun(goTool("get", "golang.org/x/mobile/cmd/gomobile", "golang.org/x/mobile/cmd/gobind"))
build.MustRun(gomobileTool("init"))
- bind := gomobileTool("bind", "-ldflags", "-s -w", "--target", "ios", "--tags", "ios", "-v", "github.com/dexon-foundation/dexon/mobile")
+ bind := gomobileTool("bind", "-ldflags", "-s -w", "--target", "ios", "--tags", "ios", "-v", "github.com/tangerine-network/go-tangerine/mobile")
if *local {
// If we're building locally, use the build folder and stop afterwards
@@ -955,7 +955,7 @@ func doXCodeFramework(cmdline []string) {
build.MustRun(bind)
return
}
- archive := "gdex-" + archiveBasename("ios", params.ArchiveVersion(env.Commit))
+ archive := "gtan-" + archiveBasename("ios", params.ArchiveVersion(env.Commit))
if err := os.Mkdir(archive, os.ModePerm); err != nil {
log.Fatal(err)
}
@@ -58,25 +58,25 @@ import (
}
- // Files that end up in the gdex-alltools*.zip archive.
+ // Files that end up in the gtan-alltools*.zip archive.
allToolsArchiveFiles = []string{
"COPYING",
@@ -752,28 +752,28 @@ func doWindowsInstaller(cmdline []string) {
}
// Render NSIS scripts: Installer NSIS contains two installer sections,
- // first section contains the gdex binary, second section holds the dev tools.
+ // first section contains the gtan binary, second section holds the dev tools.
templateData := map[string]interface{}{
"License": "COPYING",